# striebel.machamp

<a href="https://pypi.org/project/striebel.machamp/">
    <img alt="PyPI" src="https://img.shields.io/pypi/v/striebel.machamp">
</a>
<a href="https://pepy.tech/project/striebel.machamp">
    <img alt="Downloads" src="https://static.pepy.tech/badge/striebel.machamp">
</a>
<a href="https://github.com/striebel/striebel.machamp/blob/master/LICENSE">
    <img alt="License" src="https://img.shields.io/github/license/striebel/striebel.machamp">
</a>
<br/><br/>
<p>
    This repository contains stub files that can be used to create a Python project
    that is able to be packaged and uploaded to the
    <a href="https://pypi.org">Python Package Index</a>
    and hence can be conveniently installed with `pip install my-project-name`.
</p>

<p>
    This README describes how to modify the stub files, using them as the base of
    a new Python project.
    Requirements are a recent installation of Python 3 on Linux.
</p>

